GRAB
===========================

########### The method that crawlers use


########### 
You need to pass in the config.ini configuration file to use

    ini file format:    
            [database]
            host = x.x.x.x
            user = uesername
            password = pwd
            database = database
            port = 3306
            charset = utf8mb4
    
            [proxy]
            proxy_host = x.x.x.x
            proxy_port = port
            
            [headers]
            headers_ = {"user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.92 Safari/537.36"}



########### BETA V0.1.x Update of version Content

    1. Connect to the mysql database class     MysqlDB
    2. Download page various methods      Downloader
    3. Simple tools             tools